pub struct CommonFactorAttack;Expand description
Common factor attack for multiple RSA keys
When multiple RSA moduli share a common prime factor, their GCD reveals that factor. This attack computes GCD of all pairs of moduli to find common factors.
See https://en.wikipedia.org/wiki/RSA_(cryptosystem)#Practical_attacks